using System;
using System.Collections.Generic;
using System.Text;

using Sensr;

namespace init1
{
  class Program
  {
    static void Main(string[] args)
    {
      Init_Event();
    }

    static private void Init_Event()
    {
      ttr gp = new ttr();
      ttr.DeviceConfig DeviceConfig = new ttr.DeviceConfig();

      // **** Device Config ****
      // Set up the DeviceConfig class with the desired settings. In this example we
      // are olny enabling the event recorder and configuring it to use button press
      // start and stop triggers

      // Basic configuration
      // Select the desired recodring modes (Data recorder and/or event recorder) and
      // specify what percentage of memory to allocate to the data recorder if both
      // recorders are enabled, note that all memory is automatically allocated the
      // the enabled recorder if it is the only one enabled, the percentage is ignored.
      DeviceConfig.SetModeEnable(false, true, 0.0); // Enable event recorder only

      // Specify the desired accelerometer G range. The grange parameter is an index into
      // a table inside the unit. You can query the unit for what g ranges it supports
      // with the GetDeviceCaps method.
      DeviceConfig.Accel_Range = 0;

      // Disable remote start
      DeviceConfig.Remote_Start = false;

      // Disable delayed start
      DeviceConfig.Delayed_Start = 0;

      // Set the mission notes, if desired
      DeviceConfig.Notes = "Mission ID Notes";

      // Measurement: Event Recorder
      // Select the trigger condition that will cause the GP1 to start recording data
      DeviceConfig.ER_Set_Trigger_Start = ttr.DeviceConfig.ER_Trigger_Start.Button;

      // Select the trigger condition that will cause the GP1 to stop recording data
      DeviceConfig.ER_Set_Trigger_Stop = ttr.DeviceConfig.ER_Trigger_Stop.Button;

      // Specify the how much data you wish to record prior the the start trigger. The
      // GP1 is always sampling data into a circular buffer waiting for a trigger to 
      // occur, when the trigger accurs the GP1 can store upto 1 second of data prior
      // to the trigger. This is more useful when using motion tiggers, not the button
      // as used in this example
      DeviceConfig.ER_Set_PreTrig_Time = 0.0; // Seconds of pre trigger data. Range 0.0 - 1.0

      // Tells the GP1 to overide the default LED status operation and use to to indicate
      // if the device is recording data or paused.
      DeviceConfig.ER_Set_LED_Status = false;

      try
      {
        // Connect to first available device, there are overloaded
        // versions of Connect that allow you to specify which device
        // to connect to.
        gp.Connect();

        // Disables Monitoring(Epoch data processing)
        gp.MonitorDisable();

        // Erase any existing data currently stored in unti
        gp.EraseData();

        // Set the device configuration
        gp.SetDeviceConfig(DeviceConfig);

        // Clear out sample buffer in device
        gp.AccelPurge();

        // Enable the device to start monitoring
        gp.MonitorEnable();

        // Must start the device manually if no remote or delayed start option was selected
        if (!DeviceConfig.Remote_Start && (DeviceConfig.Delayed_Start == 0)) gp.SoftwareTrigger();
      }
      catch (Exception e)
      {
        Console.WriteLine("{0}", e);
      }
      finally
      {
        gp.Disconnect();
      }
    }
  }
}
